import { gettext } from "django";
import { CSSResult, customElement, html, property, TemplateResult } from "lit-element";
import { WithUserInfoChallenge } from "../../../api/Flows";
import { COMMON_STYLES } from "../../../common/styles";
import { BaseStage } from "../base";
import "../../../elements/utils/LoadingState";

export interface Permission {
    name: string;
    id: string;
}

export interface ConsentChallenge extends WithUserInfoChallenge {

    header_text: string;
    permissions?: Permission[];

}

@customElement("ak-stage-consent")
export class ConsentStage extends BaseStage {

    @property({ attribute: false })
    challenge?: ConsentChallenge;

    static get styles(): CSSResult[] {
        return COMMON_STYLES;
    }

    render(): TemplateResult {
        if (!this.challenge) {
            return html`<ak-loading-state></ak-loading-state>`;
        }
        return html`<header class="pf-c-login__main-header">
                <h1 class="pf-c-title pf-m-3xl">
                    ${this.challenge.title}
                </h1>
            </header>
            <div class="pf-c-login__main-body">
                <form class="pf-c-form" @submit=${(e: Event) => { this.submitForm(e); }}>
                    <div class="pf-c-form__group">
                        <div class="form-control-static">
                            <div class="left">
                                <img class="pf-c-avatar" src="${this.challenge.pending_user_avatar}" alt="${gettext("User's avatar")}">
                                ${this.challenge.pending_user}
                            </div>
                            <div class="right">
                                <a href="/flows/-/cancel/">${gettext("Not you?")}</a>
                            </div>
                        </div>
                    </div>

                    <div class="pf-c-form__group">
                        <p id="header-text">
                            ${this.challenge.header_text}
                        </p>
                        <p>${gettext("Application requires following permissions")}</p>
                        <ul class="pf-c-list" id="permmissions">
                            ${(this.challenge.permissions || []).map((permission) => {
                                return html`<li data-permission-code="${permission.id}">${permission.name}</li>`;
                            })}
                        </ul>
                    </div>

                    <div class="pf-c-form__group pf-m-action">
                        <button type="submit" class="pf-c-button pf-m-primary pf-m-block">
                            ${gettext("Continue")}
                        </button>
                    </div>
                </form>
            </div>
            <footer class="pf-c-login__main-footer">
                <ul class="pf-c-login__main-footer-links">
                </ul>
            </footer>`;
    }

}
